@@ -17,10 +17,19 @@ HW.original <- function (data, cod, Nsim=500) {
 }
 
 
-.First.lib <- function(libname, pkgname) {
+#.First.lib <- function(libname, pkgname) {
+# library.dynam("nsRFA", pkgname, libname)
+#}
+.onLoad <- function(libname, pkgname){
+ # do whatever needs to be done when the package is loaded
+ # some people use it to bombard users with 
+ # messages using 
+ #packageStartupMessage( "my package is so cool" )
+ #packageStartupMessage( "so I will print these lines each time you load it")
  library.dynam("nsRFA", pkgname, libname)
 }
 
+
 # ------------------------------------------------------------------- #
 
 print.HWorig <- function(x, ...) {
